*=================================================================================================================================================
* Date : 2024-01-04
* Stata version : Stata 18 SE
*
* This program creates dataset with DIF for a randomized controlled trial scenario.
* 7 items
*
* ado-files needed : - simirt (version 4.3 August 29, 2019, available on OSF)
*
  * outputs : scenario_13,scenario_14,scenario_15,scenario_16,scenario_17,scenario_18,scenario_19,scenario_20 for N=100
*
*
* Warning : To obtain reproduce the data obtained in the .csv files in this repository, use 'simirt_setseed.ado' instead of 'simirt.ado'
*
*================================================================================================================================================

* Load simirt.ado
adopath+"/home/corentin/Documents/These/Recherche/Simulations/Modules/"

* Set data output folder path

local path = "/home/corentin/Documents/These/Recherche/Simulations/Data/DIF/N100"
local Nn = 100


*==========================
* Scenarios with : J=7
*==========================

************** Scenarios with : DIF on 2 items **************

**** Scenarios with : DIF size 0.3 ****

** Scenario 13: J = 7 items / M = 2 modalities / DIF SIZE = 0.3

* Scenario 13A : H_0 is TRUE / DIF on treatment x 2

di "Scenario 13A - N=100"

forvalues replication = 1/1000 {
  clear
  if mod(`replication',100)==0 {
  di "replication = `replication'"
  }
  qui set obs 7
  qui gen xxx = _n
  qui sample 2 ,count
  qui valuesof xxx
  qui local ItemsDIF = r(values)
  qui local difi :  word 1 of `ItemsDIF'
  qui local difj :  word 2 of `ItemsDIF'


    mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 0
		tempfile grp0
		qui save `grp0',replace




    mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
    if `difi'==1 {
      mat E=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difi'==2 {
      mat E=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difi'==3 {
      mat E=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
    }
    if `difi'==4 {
      mat E=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
    }
    if `difi'==5 {
      mat E=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
    }
    if `difi'==6 {
      mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
    }
    if `difi'==7 {
      mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
    }
    if `difj'==1 {
      mat F=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difj'==2 {
      mat F=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difj'==3 {
      mat F=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
    }
    if `difj'==4 {
      mat F=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
    }
    if `difj'==5 {
      mat F=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
    }
    if `difj'==6 {
      mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
    }
    if `difj'==7 {
      mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
    }
    mat D=B+E+F
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 1
		tempfile grp1
		qui save `grp1',replace


		clear
		use `grp0'
    qui append using `grp1'
		drop id
    qui gen dif1 = `difi'
    qui gen dif2 = `difj'
		qui gen id = _n
		order(id)
		qui gen replication = `replication'
		if `replication'==1{
			tempfile data
			qui save `data'
		}
		else{
			qui append using `data'
			qui save `data',replace
		}
	}
	export delimited using "`path'/scenario_13A_100.csv", replace


  * Scenario 13B : H_1 is TRUE / Effect size 0.2 / DIF on treatment x2

  di "Scenario 13B - N=100"

  forvalues replication = 1/1000 {
    clear
    if mod(`replication',100)==0 {
    di "replication = `replication'"
    }
    qui set obs 7
    qui gen xxx = _n
    qui sample 2 ,count
    qui valuesof xxx
    qui local ItemsDIF = r(values)
    qui local difi :  word 1 of `ItemsDIF'
    qui local difj :  word 2 of `ItemsDIF'


      mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
  		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
      qui gen TT = 0
  		tempfile grp0
  		qui save `grp0',replace


      mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
      if `difi'==1 {
        mat E=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==2 {
        mat E=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==3 {
        mat E=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==4 {
        mat E=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
      }
      if `difi'==5 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
      }
      if `difi'==6 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
      }
      if `difi'==7 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
      }
      if `difj'==1 {
        mat F=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==2 {
        mat F=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==3 {
        mat F=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==4 {
        mat F=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
      }
      if `difj'==5 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
      }
      if `difj'==6 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
      }
      if `difj'==7 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
      }
      mat D=B+E+F
  		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
      qui gen TT = 1
  		tempfile grp1
  		qui save `grp1',replace


  		clear
  		use `grp0'
      qui append using `grp1'
  		drop id
      qui gen dif1 = `difi'
      qui gen dif2 = `difj'
  		qui gen id = _n
  		order(id)
  		qui gen replication = `replication'
  		if `replication'==1{
  			tempfile data
  			qui save `data'
  		}
  		else{
  			qui append using `data'
  			qui save `data',replace
  		}
  	}
  	export delimited using "`path'/scenario_13B_100.csv", replace

* Scenario 13C : H_1 is TRUE / Effect size 0.2 / DIF on control x2

    di "Scenario 13C - N=100"

    forvalues replication = 1/1000 {
      clear
      if mod(`replication',100)==0 {
      di "replication = `replication'"
      }
      qui set obs 7
      qui gen xxx = _n
      qui sample 2 ,count
      qui valuesof xxx
      qui local ItemsDIF = r(values)
      qui local difi :  word 1 of `ItemsDIF'
      qui local difj :  word 2 of `ItemsDIF'


      mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
      if `difi'==1 {
        mat E=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==2 {
        mat E=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==3 {
        mat E=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==4 {
        mat E=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
      }
      if `difi'==5 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
      }
      if `difi'==6 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
      }
      if `difi'==7 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
      }
      if `difj'==1 {
        mat F=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==2 {
        mat F=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==3 {
        mat F=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==4 {
        mat F=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
      }
      if `difj'==5 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
      }
      if `difj'==6 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
      }
      if `difj'==7 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
      }
      mat D=B+E+F
    		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
        qui gen TT = 0
    		tempfile grp0
    		qui save `grp0',replace


        mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
    		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
        qui gen TT = 1
    		tempfile grp1
    		qui save `grp1',replace


    		clear
    		use `grp0'
        qui append using `grp1'
    		drop id
        qui gen dif1 = `difi'
        qui gen dif2 = `difj'
    		qui gen id = _n
    		order(id)
    		qui gen replication = `replication'
    		if `replication'==1{
    			tempfile data
    			qui save `data'
    		}
    		else{
    			qui append using `data'
    			qui save `data',replace
    		}
    	}
    	export delimited using "`path'/scenario_13C_100.csv", replace


* Scenario 13D : H_1 is TRUE / Effect size 0.4 / DIF on treatment x2

        di "Scenario 13D - N=100"

        forvalues replication = 1/1000 {
          clear
          if mod(`replication',100)==0 {
          di "replication = `replication'"
          }
          qui set obs 7
          qui gen xxx = _n
          qui sample 2 ,count
          qui valuesof xxx
          qui local ItemsDIF = r(values)
          qui local difi :  word 1 of `ItemsDIF'
          qui local difj :  word 2 of `ItemsDIF'

            mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
        		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
            qui gen TT = 0
        		tempfile grp0
        		qui save `grp0',replace


            mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
            if `difi'==1 {
              mat E=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
            }
            if `difi'==2 {
              mat E=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
            }
            if `difi'==3 {
              mat E=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
            }
            if `difi'==4 {
              mat E=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
            }
            if `difi'==5 {
              mat E=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
            }
            if `difi'==6 {
              mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
            }
            if `difi'==7 {
              mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
            }
            if `difj'==1 {
              mat F=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
            }
            if `difj'==2 {
              mat F=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
            }
            if `difj'==3 {
              mat F=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
            }
            if `difj'==4 {
              mat F=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
            }
            if `difj'==5 {
              mat F=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
            }
            if `difj'==6 {
              mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
            }
            if `difj'==7 {
              mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
            }
            mat D=B+E+F
        		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
            qui gen TT = 1
        		tempfile grp1
        		qui save `grp1',replace


        		clear
        		use `grp0'
            qui append using `grp1'
        		drop id
            qui gen dif1 = `difi'
            qui gen dif2 = `difj'
        		qui gen id = _n
        		order(id)
        		qui gen replication = `replication'
        		if `replication'==1{
        			tempfile data
        			qui save `data'
        		}
        		else{
        			qui append using `data'
        			qui save `data',replace
        		}
        	}
        	export delimited using "`path'/scenario_13D_100.csv", replace

* Scenario 13E : H_1 is TRUE / Effect size 0.4 / DIF on control x2

          di "Scenario 13E - N=100"

          forvalues replication = 1/1000 {
            clear
            if mod(`replication',100)==0 {
            di "replication = `replication'"
            }
            qui set obs 7
            qui gen xxx = _n
            qui sample 2 ,count
            qui valuesof xxx
            qui local ItemsDIF = r(values)
            qui local difi :  word 1 of `ItemsDIF'
            qui local difj :  word 2 of `ItemsDIF'

            mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
            if `difi'==1 {
              mat E=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
            }
            if `difi'==2 {
              mat E=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
            }
            if `difi'==3 {
              mat E=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
            }
            if `difi'==4 {
              mat E=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
            }
            if `difi'==5 {
              mat E=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
            }
            if `difi'==6 {
              mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
            }
            if `difi'==7 {
              mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
            }
            if `difj'==1 {
              mat F=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
            }
            if `difj'==2 {
              mat F=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
            }
            if `difj'==3 {
              mat F=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
            }
            if `difj'==4 {
              mat F=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
            }
            if `difj'==5 {
              mat F=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
            }
            if `difj'==6 {
              mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
            }
            if `difj'==7 {
              mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
            }
            mat D=B+E+F
          		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
              qui gen TT = 0
          		tempfile grp0
          		qui save `grp0',replace


              mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
          		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
              qui gen TT = 1
          		tempfile grp1
          		qui save `grp1',replace


          		clear
          		use `grp0'
              qui append using `grp1'
          		drop id
              qui gen dif1 = `difi'
              qui gen dif2 = `difj'
          		qui gen id = _n
          		order(id)
          		qui gen replication = `replication'
          		if `replication'==1{
          			tempfile data
          			qui save `data'
          		}
          		else{
          			qui append using `data'
          			qui save `data',replace
          		}
          	}
          	export delimited using "`path'/scenario_13E_100.csv", replace




** Scenario 14: J = 7 items / M = 4 modalities / DIF SIZE = 0.3

* Scenario 14A : H_0 is TRUE / DIF on treatment x 2

di "Scenario 14A - N=100"

forvalues replication = 1/1000 {
  clear
  if mod(`replication',100)==0 {
  di "replication = `replication'"
  }
  qui set obs 7
  qui gen xxx = _n
  qui sample 2 ,count
  qui valuesof xxx
  qui local ItemsDIF = r(values)
  qui local difi :  word 1 of `ItemsDIF'
  qui local difj :  word 2 of `ItemsDIF'

    mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 0
		tempfile grp0
		qui save `grp0',replace


    mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
    if `difi'==1 {
      mat E=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==2 {
      mat E=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==3 {
      mat E=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==4 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==5 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==6 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
    }
    if `difi'==7 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
    }
    if `difj'==1 {
      mat F=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==2 {
      mat F=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==3 {
      mat F=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==4 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==5 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==6 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
    }
    if `difj'==7 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
    }
    mat D=B+E+F
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 1
		tempfile grp1
		qui save `grp1',replace


		clear
		use `grp0'
    qui append using `grp1'
		drop id
    qui gen dif1 = `difi'
    qui gen dif2 = `difj'
		qui gen id = _n
		order(id)
		qui gen replication = `replication'
		if `replication'==1{
			tempfile data
			qui save `data'
		}
		else{
			qui append using `data'
			qui save `data',replace
		}
	}
	export delimited using "`path'/scenario_14A_100.csv", replace


  * Scenario 14B : H_1 is TRUE / Effect size 0.2 / DIF on treatment x2

  di "Scenario 14B - N=100"

  forvalues replication = 1/1000 {
    clear
    if mod(`replication',100)==0 {
    di "replication = `replication'"
    }
    qui set obs 7
    qui gen xxx = _n
    qui sample 2 ,count
    qui valuesof xxx
    qui local ItemsDIF = r(values)
    qui local difi :  word 1 of `ItemsDIF'
    qui local difj :  word 2 of `ItemsDIF'

      mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
  		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
      qui gen TT = 0
  		tempfile grp0
  		qui save `grp0',replace


      mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
      if `difi'==1 {
        mat E=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==2 {
        mat E=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==3 {
        mat E=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==4 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==5 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==6 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
      }
      if `difi'==7 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
      }
      if `difj'==1 {
        mat F=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==2 {
        mat F=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==3 {
        mat F=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==4 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==5 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==6 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
      }
      if `difj'==7 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
      }
      mat D=B+E+F
  		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
      qui gen TT = 1
  		tempfile grp1
  		qui save `grp1',replace


  		clear
  		use `grp0'
      qui append using `grp1'
  		drop id
      qui gen dif1 = `difi'
      qui gen dif2 = `difj'
  		qui gen id = _n
  		order(id)
  		qui gen replication = `replication'
  		if `replication'==1{
  			tempfile data
  			qui save `data'
  		}
  		else{
  			qui append using `data'
  			qui save `data',replace
  		}
  	}
  	export delimited using "`path'/scenario_14B_100.csv", replace

* Scenario 14C : H_1 is TRUE / Effect size 0.2 / DIF on control x2

    di "Scenario 14C - N=100"

    forvalues replication = 1/1000 {
      clear
      if mod(`replication',100)==0 {
      di "replication = `replication'"
      }
      qui set obs 7
      qui gen xxx = _n
      qui sample 2 ,count
      qui valuesof xxx
      qui local ItemsDIF = r(values)
      qui local difi :  word 1 of `ItemsDIF'
      qui local difj :  word 2 of `ItemsDIF'

      mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
      if `difi'==1 {
        mat E=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==2 {
        mat E=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==3 {
        mat E=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==4 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==5 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==6 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
      }
      if `difi'==7 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
      }
      if `difj'==1 {
        mat F=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==2 {
        mat F=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==3 {
        mat F=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==4 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==5 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==6 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
      }
      if `difj'==7 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
      }
      mat D=B+E+F
    		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
        qui gen TT = 0
    		tempfile grp0
    		qui save `grp0',replace


        mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
    		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
        qui gen TT = 1
    		tempfile grp1
    		qui save `grp1',replace


    		clear
    		use `grp0'
        qui append using `grp1'
    		drop id
        qui gen dif1 = `difi'
        qui gen dif2 = `difj'
    		qui gen id = _n
    		order(id)
    		qui gen replication = `replication'
    		if `replication'==1{
    			tempfile data
    			qui save `data'
    		}
    		else{
    			qui append using `data'
    			qui save `data',replace
    		}
    	}
    	export delimited using "`path'/scenario_14C_100.csv", replace


* Scenario 14D : H_1 is TRUE / Effect size 0.4 / DIF on treatment x2

        di "Scenario 14D - N=100"

        forvalues replication = 1/1000 {
          clear
          if mod(`replication',100)==0 {
          di "replication = `replication'"
          }
          qui set obs 7
          qui gen xxx = _n
          qui sample 2 ,count
          qui valuesof xxx
          qui local ItemsDIF = r(values)
          qui local difi :  word 1 of `ItemsDIF'
          qui local difj :  word 2 of `ItemsDIF'

            mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
        		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
            qui gen TT = 0
        		tempfile grp0
        		qui save `grp0',replace


            mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
            if `difi'==1 {
              mat E=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==2 {
              mat E=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==3 {
              mat E=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==4 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==5 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==6 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
            }
            if `difi'==7 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
            }
            if `difj'==1 {
              mat F=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==2 {
              mat F=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==3 {
              mat F=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==4 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==5 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==6 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
            }
            if `difj'==7 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
            }
            mat D=B+E+F
        		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
            qui gen TT = 1
        		tempfile grp1
        		qui save `grp1',replace


        		clear
        		use `grp0'
            qui append using `grp1'
        		drop id
            qui gen dif1 = `difi'
            qui gen dif2 = `difj'
        		qui gen id = _n
        		order(id)
        		qui gen replication = `replication'
        		if `replication'==1{
        			tempfile data
        			qui save `data'
        		}
        		else{
        			qui append using `data'
        			qui save `data',replace
        		}
        	}
        	export delimited using "`path'/scenario_14D_100.csv", replace

* Scenario 14E : H_1 is TRUE / Effect size 0.4 / DIF on control x2

          di "Scenario 14E - N=100"

          forvalues replication = 1/1000 {
            clear
            if mod(`replication',100)==0 {
            di "replication = `replication'"
            }
            qui set obs 7
            qui gen xxx = _n
            qui sample 2 ,count
            qui valuesof xxx
            qui local ItemsDIF = r(values)
            qui local difi :  word 1 of `ItemsDIF'
            qui local difj :  word 2 of `ItemsDIF'

            mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
            if `difi'==1 {
              mat E=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==2 {
              mat E=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==3 {
              mat E=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==4 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==5 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==6 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
            }
            if `difi'==7 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
            }
            if `difj'==1 {
              mat F=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==2 {
              mat F=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==3 {
              mat F=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==4 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==5 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==6 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
            }
            if `difj'==7 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
            }
            mat D=B+E+F
          		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
              qui gen TT = 0
          		tempfile grp0
          		qui save `grp0',replace


              mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
          		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
              qui gen TT = 1
          		tempfile grp1
          		qui save `grp1',replace


          		clear
          		use `grp0'
              qui append using `grp1'
          		drop id
              qui gen dif1 = `difi'
              qui gen dif2 = `difj'
          		qui gen id = _n
          		order(id)
          		qui gen replication = `replication'
          		if `replication'==1{
          			tempfile data
          			qui save `data'
          		}
          		else{
          			qui append using `data'
          			qui save `data',replace
          		}
          	}
          	export delimited using "`path'/scenario_14E_100.csv", replace


**** Scenarios with : DIF size 0.5 ****

** Scenario 15: J = 7 items / M = 2 modalities / DIF SIZE = 0.5

* Scenario 15A : H_0 is TRUE / DIF on treatment x 2

di "Scenario 15A - N=100"

forvalues replication = 1/1000 {
  clear
  if mod(`replication',100)==0 {
  di "replication = `replication'"
  }
  qui set obs 7
  qui gen xxx = _n
  qui sample 2 ,count
  qui valuesof xxx
  qui local ItemsDIF = r(values)
  qui local difi :  word 1 of `ItemsDIF'
  qui local difj :  word 2 of `ItemsDIF'

    mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 0
		tempfile grp0
		qui save `grp0',replace

    mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
    if `difi'==1 {
      mat E=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difi'==2 {
      mat E=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difi'==3 {
      mat E=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
    }
    if `difi'==4 {
      mat E=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
    }
    if `difi'==5 {
      mat E=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
    }
    if `difi'==6 {
      mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
    }
    if `difi'==7 {
      mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
    }
    if `difj'==1 {
      mat F=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difj'==2 {
      mat F=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difj'==3 {
      mat F=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
    }
    if `difj'==4 {
      mat F=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
    }
    if `difj'==5 {
      mat F=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
    }
    if `difj'==6 {
      mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
    }
    if `difj'==7 {
      mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
    }
    mat D=B+E+F
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 1
		tempfile grp1
		qui save `grp1',replace


		clear
		use `grp0'
    qui append using `grp1'
		drop id
    qui gen dif1 = `difi'
    qui gen dif2 = `difj'
		qui gen id = _n
		order(id)
		qui gen replication = `replication'
		if `replication'==1{
			tempfile data
			qui save `data'
		}
		else{
			qui append using `data'
			qui save `data',replace
		}
	}
	export delimited using "`path'/scenario_15A_100.csv", replace


  * Scenario 15B : H_1 is TRUE / Effect size 0.2 / DIF on treatment x2

  di "Scenario 15B - N=100"

  forvalues replication = 1/1000 {
    clear
    if mod(`replication',100)==0 {
    di "replication = `replication'"
    }
    qui set obs 7
    qui gen xxx = _n
    qui sample 2 ,count
    qui valuesof xxx
    qui local ItemsDIF = r(values)
    qui local difi :  word 1 of `ItemsDIF'
    qui local difj :  word 2 of `ItemsDIF'

      mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
  		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
      qui gen TT = 0
  		tempfile grp0
  		qui save `grp0',replace


      mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
      if `difi'==1 {
        mat E=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==2 {
        mat E=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==3 {
        mat E=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==4 {
        mat E=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
      }
      if `difi'==5 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
      }
      if `difi'==6 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
      }
      if `difi'==7 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
      }
      if `difj'==1 {
        mat F=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==2 {
        mat F=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==3 {
        mat F=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==4 {
        mat F=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
      }
      if `difj'==5 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
      }
      if `difj'==6 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
      }
      if `difj'==7 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
      }
      mat D=B+E+F
  		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
      qui gen TT = 1
  		tempfile grp1
  		qui save `grp1',replace


  		clear
  		use `grp0'
      qui append using `grp1'
  		drop id
      qui gen dif1 = `difi'
      qui gen dif2 = `difj'
  		qui gen id = _n
  		order(id)
  		qui gen replication = `replication'
  		if `replication'==1{
  			tempfile data
  			qui save `data'
  		}
  		else{
  			qui append using `data'
  			qui save `data',replace
  		}
  	}
  	export delimited using "`path'/scenario_15B_100.csv", replace

* Scenario 15C : H_1 is TRUE / Effect size 0.2 / DIF on control x2

    di "Scenario 15C - N=100"

    forvalues replication = 1/1000 {
      clear
      if mod(`replication',100)==0 {
      di "replication = `replication'"
      }
      qui set obs 7
      qui gen xxx = _n
      qui sample 2 ,count
      qui valuesof xxx
      qui local ItemsDIF = r(values)
      qui local difi :  word 1 of `ItemsDIF'
      qui local difj :  word 2 of `ItemsDIF'

        mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
        if `difi'==1 {
          mat E=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
        }
        if `difi'==2 {
          mat E=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
        }
        if `difi'==3 {
          mat E=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
        }
        if `difi'==4 {
          mat E=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
        }
        if `difi'==5 {
          mat E=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
        }
        if `difi'==6 {
          mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
        }
        if `difi'==7 {
          mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
        }
        if `difj'==1 {
          mat F=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
        }
        if `difj'==2 {
          mat F=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
        }
        if `difj'==3 {
          mat F=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
        }
        if `difj'==4 {
          mat F=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
        }
        if `difj'==5 {
          mat F=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
        }
        if `difj'==6 {
          mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
        }
        if `difj'==7 {
          mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
        }
        mat D=B+E+F
    		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
        qui gen TT = 0
    		tempfile grp0
    		qui save `grp0',replace


        mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
    		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
        qui gen TT = 1
    		tempfile grp1
    		qui save `grp1',replace


    		clear
    		use `grp0'
        qui append using `grp1'
    		drop id
        qui gen dif1 = `difi'
        qui gen dif2 = `difj'
    		qui gen id = _n
    		order(id)
    		qui gen replication = `replication'
    		if `replication'==1{
    			tempfile data
    			qui save `data'
    		}
    		else{
    			qui append using `data'
    			qui save `data',replace
    		}
    	}
    	export delimited using "`path'/scenario_15C_100.csv", replace


* Scenario 15D : H_1 is TRUE / Effect size 0.4 / DIF on treatment x2

        di "Scenario 15D - N=100"

        forvalues replication = 1/1000 {
          clear
          if mod(`replication',100)==0 {
          di "replication = `replication'"
          }
          qui set obs 7
          qui gen xxx = _n
          qui sample 2 ,count
          qui valuesof xxx
          qui local ItemsDIF = r(values)
          qui local difi :  word 1 of `ItemsDIF'
          qui local difj :  word 2 of `ItemsDIF'

            mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
        		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
            qui gen TT = 0
        		tempfile grp0
        		qui save `grp0',replace


            mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
            if `difi'==1 {
              mat E=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
            }
            if `difi'==2 {
              mat E=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
            }
            if `difi'==3 {
              mat E=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
            }
            if `difi'==4 {
              mat E=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
            }
            if `difi'==5 {
              mat E=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
            }
            if `difi'==6 {
              mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
            }
            if `difi'==7 {
              mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
            }
            if `difj'==1 {
              mat F=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
            }
            if `difj'==2 {
              mat F=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
            }
            if `difj'==3 {
              mat F=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
            }
            if `difj'==4 {
              mat F=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
            }
            if `difj'==5 {
              mat F=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
            }
            if `difj'==6 {
              mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
            }
            if `difj'==7 {
              mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
            }
            mat D=B+E+F
        		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
            qui gen TT = 1
        		tempfile grp1
        		qui save `grp1',replace


        		clear
        		use `grp0'
            qui append using `grp1'
        		drop id
            qui gen dif1 = `difi'
            qui gen dif2 = `difj'
        		qui gen id = _n
        		order(id)
        		qui gen replication = `replication'
        		if `replication'==1{
        			tempfile data
        			qui save `data'
        		}
        		else{
        			qui append using `data'
        			qui save `data',replace
        		}
        	}
        	export delimited using "`path'/scenario_15D_100.csv", replace

* Scenario 15E : H_1 is TRUE / Effect size 0.4 / DIF on control x2

          di "Scenario 15E - N=100"

          forvalues replication = 1/1000 {
            clear
            if mod(`replication',100)==0 {
            di "replication = `replication'"
            }
            qui set obs 7
            qui gen xxx = _n
            qui sample 2 ,count
            qui valuesof xxx
            qui local ItemsDIF = r(values)
            qui local difi :  word 1 of `ItemsDIF'
            qui local difj :  word 2 of `ItemsDIF'

              mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
              if `difi'==1 {
                mat E=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difi'==2 {
                mat E=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difi'==3 {
                mat E=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
              }
              if `difi'==4 {
                mat E=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
              }
              if `difi'==5 {
                mat E=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
              }
              if `difi'==6 {
                mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
              }
              if `difi'==7 {
                mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
              }
              if `difj'==1 {
                mat F=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difj'==2 {
                mat F=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difj'==3 {
                mat F=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
              }
              if `difj'==4 {
                mat F=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
              }
              if `difj'==5 {
                mat F=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
              }
              if `difj'==6 {
                mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
              }
              if `difj'==7 {
                mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
              }
              mat D=B+E+F
          		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
              qui gen TT = 0
          		tempfile grp0
          		qui save `grp0',replace


              mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
          		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
              qui gen TT = 1
          		tempfile grp1
          		qui save `grp1',replace


          		clear
          		use `grp0'
              qui append using `grp1'
          		drop id
              qui gen dif1 = `difi'
              qui gen dif2 = `difj'
          		qui gen id = _n
          		order(id)
          		qui gen replication = `replication'
          		if `replication'==1{
          			tempfile data
          			qui save `data'
          		}
          		else{
          			qui append using `data'
          			qui save `data',replace
          		}
          	}
          	export delimited using "`path'/scenario_15E_100.csv", replace




** Scenario 16: J = 7 items / M = 4 modalities / DIF SIZE = 0.5

* Scenario 16A : H_0 is TRUE / DIF on treatment x 2

di "Scenario 16A - N=100"

forvalues replication = 1/1000 {
  clear
  if mod(`replication',100)==0 {
  di "replication = `replication'"
  }
  qui set obs 7
  qui gen xxx = _n
  qui sample 2 ,count
  qui valuesof xxx
  qui local ItemsDIF = r(values)
  qui local difi :  word 1 of `ItemsDIF'
  qui local difj :  word 2 of `ItemsDIF'

    mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 0
		tempfile grp0
		qui save `grp0',replace


    mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
    if `difi'==1 {
      mat E=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==2 {
      mat E=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==3 {
      mat E=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==4 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==5 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==6 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
    }
    if `difi'==7 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
    }
    if `difj'==1 {
      mat F=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==2 {
      mat F=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==3 {
      mat F=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==4 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==5 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==6 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
    }
    if `difj'==7 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
    }
    mat D=B+E+F
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 1
		tempfile grp1
		qui save `grp1',replace


		clear
		use `grp0'
    qui append using `grp1'
		drop id
    qui gen dif1 = `difi'
    qui gen dif2 = `difj'
		qui gen id = _n
		order(id)
		qui gen replication = `replication'
		if `replication'==1{
			tempfile data
			qui save `data'
		}
		else{
			qui append using `data'
			qui save `data',replace
		}
	}
	export delimited using "`path'/scenario_16A_100.csv", replace


  * Scenario 16B : H_1 is TRUE / Effect size 0.2 / DIF on treatment x2

  di "Scenario 16B - N=100"

  forvalues replication = 1/1000 {
    clear
    if mod(`replication',100)==0 {
    di "replication = `replication'"
    }
    qui set obs 7
    qui gen xxx = _n
    qui sample 2 ,count
    qui valuesof xxx
    qui local ItemsDIF = r(values)
    qui local difi :  word 1 of `ItemsDIF'
    qui local difj :  word 2 of `ItemsDIF'

      mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
  		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
      qui gen TT = 0
  		tempfile grp0
  		qui save `grp0',replace


      mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
      if `difi'==1 {
        mat E=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==2 {
        mat E=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==3 {
        mat E=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==4 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==5 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==6 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
      }
      if `difi'==7 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
      }
      if `difj'==1 {
        mat F=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==2 {
        mat F=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==3 {
        mat F=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==4 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==5 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==6 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
      }
      if `difj'==7 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
      }
      mat D=B+E+F
  		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
      qui gen TT = 1
  		tempfile grp1
  		qui save `grp1',replace


  		clear
  		use `grp0'
      qui append using `grp1'
  		drop id
      qui gen dif1 = `difi'
      qui gen dif2 = `difj'
  		qui gen id = _n
  		order(id)
  		qui gen replication = `replication'
  		if `replication'==1{
  			tempfile data
  			qui save `data'
  		}
  		else{
  			qui append using `data'
  			qui save `data',replace
  		}
  	}
  	export delimited using "`path'/scenario_16B_100.csv", replace

* Scenario 16C : H_1 is TRUE / Effect size 0.2 / DIF on control x2

    di "Scenario 16C - N=100"

    forvalues replication = 1/1000 {
      clear
      if mod(`replication',100)==0 {
      di "replication = `replication'"
      }
      qui set obs 7
      qui gen xxx = _n
      qui sample 2 ,count
      qui valuesof xxx
      qui local ItemsDIF = r(values)
      qui local difi :  word 1 of `ItemsDIF'
      qui local difj :  word 2 of `ItemsDIF'

      mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
      if `difi'==1 {
        mat E=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==2 {
        mat E=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==3 {
        mat E=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==4 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==5 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==6 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
      }
      if `difi'==7 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
      }
      if `difj'==1 {
        mat F=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==2 {
        mat F=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==3 {
        mat F=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==4 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==5 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==6 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
      }
      if `difj'==7 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
      }
      mat D=B+E+F
    		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
        qui gen TT = 0
    		tempfile grp0
    		qui save `grp0',replace


        mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
    		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
        qui gen TT = 1
    		tempfile grp1
    		qui save `grp1',replace


    		clear
    		use `grp0'
        qui append using `grp1'
    		drop id
        qui gen dif1 = `difi'
        qui gen dif2 = `difj'
    		qui gen id = _n
    		order(id)
    		qui gen replication = `replication'
    		if `replication'==1{
    			tempfile data
    			qui save `data'
    		}
    		else{
    			qui append using `data'
    			qui save `data',replace
    		}
    	}
    	export delimited using "`path'/scenario_16C_100.csv", replace


* Scenario 16D : H_1 is TRUE / Effect size 0.4 / DIF on treatment x2

        di "Scenario 16D - N=100"

        forvalues replication = 1/1000 {
          clear
          if mod(`replication',100)==0 {
          di "replication = `replication'"
          }
          qui set obs 7
          qui gen xxx = _n
          qui sample 2 ,count
          qui valuesof xxx
          qui local ItemsDIF = r(values)
          qui local difi :  word 1 of `ItemsDIF'
          qui local difj :  word 2 of `ItemsDIF'

            mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
        		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
            qui gen TT = 0
        		tempfile grp0
        		qui save `grp0',replace


            mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
            if `difi'==1 {
              mat E=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==2 {
              mat E=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==3 {
              mat E=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==4 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==5 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==6 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
            }
            if `difi'==7 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
            }
            if `difj'==1 {
              mat F=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==2 {
              mat F=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==3 {
              mat F=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==4 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==5 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==6 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
            }
            if `difj'==7 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
            }
            mat D=B+E+F
        		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
            qui gen TT = 1
        		tempfile grp1
        		qui save `grp1',replace


        		clear
        		use `grp0'
            qui append using `grp1'
        		drop id
            qui gen dif1 = `difi'
            qui gen dif2 = `difj'
        		qui gen id = _n
        		order(id)
        		qui gen replication = `replication'
        		if `replication'==1{
        			tempfile data
        			qui save `data'
        		}
        		else{
        			qui append using `data'
        			qui save `data',replace
        		}
        	}
        	export delimited using "`path'/scenario_16D_100.csv", replace

* Scenario 16E : H_1 is TRUE / Effect size 0.4 / DIF on control x2

          di "Scenario 16E - N=100"

          forvalues replication = 1/1000 {
            clear
            if mod(`replication',100)==0 {
            di "replication = `replication'"
            }
            qui set obs 7
            qui gen xxx = _n
            qui sample 2 ,count
            qui valuesof xxx
            qui local ItemsDIF = r(values)
            qui local difi :  word 1 of `ItemsDIF'
            qui local difj :  word 2 of `ItemsDIF'

            mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
            if `difi'==1 {
              mat E=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==2 {
              mat E=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==3 {
              mat E=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==4 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==5 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
            }
            if `difi'==6 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
            }
            if `difi'==7 {
              mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
            }
            if `difj'==1 {
              mat F=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==2 {
              mat F=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==3 {
              mat F=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==4 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==5 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
            }
            if `difj'==6 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
            }
            if `difj'==7 {
              mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
            }
            mat D=B+E+F
          		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
              qui gen TT = 0
          		tempfile grp0
          		qui save `grp0',replace


              mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
          		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
              qui gen TT = 1
          		tempfile grp1
          		qui save `grp1',replace


          		clear
          		use `grp0'
              qui append using `grp1'
          		drop id
              qui gen dif1 = `difi'
              qui gen dif2 = `difj'
          		qui gen id = _n
          		order(id)
          		qui gen replication = `replication'
          		if `replication'==1{
          			tempfile data
          			qui save `data'
          		}
          		else{
          			qui append using `data'
          			qui save `data',replace
          		}
          	}
          	export delimited using "`path'/scenario_16E_100.csv", replace





************** Scenarios with : DIF on 3 items **************

**** Scenarios with : DIF size 0.3 ****

** Scenario 17: J = 7 items / M = 2 modalities / DIF SIZE = 0.3

* Scenario 17A : H_0 is TRUE / DIF on treatment x3
di "Scenario 17A - N=100"

forvalues replication = 1/1000 {
  clear
  if mod(`replication',100)==0 {
  di "replication = `replication'"
  }
  qui set obs 7
  qui gen xxx = _n
  qui sample 3 ,count
  qui valuesof xxx
  qui local ItemsDIF = r(values)
  qui local difi :  word 1 of `ItemsDIF'
  qui local difj :  word 2 of `ItemsDIF'
  qui local difk :  word 3 of `ItemsDIF'


    mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 0
		tempfile grp0
		qui save `grp0',replace


    mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
    if `difi'==1 {
      mat E=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difi'==2 {
      mat E=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difi'==3 {
      mat E=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
    }
    if `difi'==4 {
      mat E=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
    }
    if `difi'==5 {
      mat E=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
    }
    if `difi'==6 {
      mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
    }
    if `difi'==7 {
      mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
    }
    if `difj'==1 {
      mat F=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difj'==2 {
      mat F=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difj'==3 {
      mat F=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
    }
    if `difj'==4 {
      mat F=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
    }
    if `difj'==5 {
      mat F=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
    }
    if `difj'==6 {
      mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
    }
    if `difj'==7 {
      mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
    }
    if `difk'==1 {
      mat G=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difk'==2 {
      mat G=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difk'==3 {
      mat G=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
    }
    if `difk'==4 {
      mat G=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
    }
    if `difk'==5 {
      mat G=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
    }
    if `difk'==6 {
      mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
    }
    if `difk'==7 {
      mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
    }
    mat D=B+E+F+G
    di
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 1
		tempfile grp1
		qui save `grp1',replace


		clear
		use `grp0'
    qui append using `grp1'
		drop id
    qui gen dif1 = `difi'
    qui gen dif2 = `difj'
    qui gen dif3 = `difk'
		qui gen id = _n
		order(id)
		qui gen replication = `replication'
		if `replication'==1{
			tempfile data
			qui save `data'
		}
		else{
			qui append using `data'
			qui save `data',replace
		}
	}
	export delimited using "`path'/scenario_17A_100.csv", replace


* Scenario 17B : H_1 is TRUE / Effect size 0.2 / DIF on treatment x3

di "Scenario 17B - N=100"

  forvalues replication = 1/1000 {
    clear
    if mod(`replication',100)==0 {
    di "replication = `replication'"
    }
    qui set obs 7
    qui gen xxx = _n
    qui sample 3 ,count
    qui valuesof xxx
    qui local ItemsDIF = r(values)
    qui local difi :  word 1 of `ItemsDIF'
    qui local difj :  word 2 of `ItemsDIF'
    qui local difk :  word 3 of `ItemsDIF'



      mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
  		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
      qui gen TT = 0
  		tempfile grp0
  		qui save `grp0',replace


      mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
      if `difi'==1 {
        mat E=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==2 {
        mat E=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==3 {
        mat E=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==4 {
        mat E=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
      }
      if `difi'==5 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
      }
      if `difi'==6 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
      }
      if `difi'==7 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
      }
      if `difj'==1 {
        mat F=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==2 {
        mat F=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==3 {
        mat F=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==4 {
        mat F=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
      }
      if `difj'==5 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
      }
      if `difj'==6 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
      }
      if `difj'==7 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
      }
      if `difk'==1 {
        mat G=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difk'==2 {
        mat G=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difk'==3 {
        mat G=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
      }
      if `difk'==4 {
        mat G=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
      }
      if `difk'==5 {
        mat G=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
      }
      if `difk'==6 {
        mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
      }
      if `difk'==7 {
        mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
      }
      mat D=B+E+F+G
  		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
      qui gen TT = 1
  		tempfile grp1
  		qui save `grp1',replace


  		clear
  		use `grp0'
      qui append using `grp1'
  		drop id
      qui gen dif1 = `difi'
      qui gen dif2 = `difj'
      qui gen dif3 = `difk'
  		qui gen id = _n
  		order(id)
  		qui gen replication = `replication'
  		if `replication'==1{
  			tempfile data
  			qui save `data'
  		}
  		else{
  			qui append using `data'
  			qui save `data',replace
  		}
  	}
  	export delimited using "`path'/scenario_17B_100.csv", replace











* Scenario 17C : H_1 is TRUE / Effect size 0.2 / DIF on control x3

    di "Scenario 17C - N=100"

      forvalues replication = 1/1000 {
        clear
        if mod(`replication',100)==0 {
        di "replication = `replication'"
        }
        qui set obs 7
        qui gen xxx = _n
        qui sample 3 ,count
        qui valuesof xxx
        qui local ItemsDIF = r(values)
        qui local difi :  word 1 of `ItemsDIF'
        qui local difj :  word 2 of `ItemsDIF'
        qui local difk :  word 3 of `ItemsDIF'



          mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
          if `difi'==1 {
            mat E=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
          }
          if `difi'==2 {
            mat E=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
          }
          if `difi'==3 {
            mat E=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
          }
          if `difi'==4 {
            mat E=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
          }
          if `difi'==5 {
            mat E=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
          }
          if `difi'==6 {
            mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
          }
          if `difi'==7 {
            mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
          }
          if `difj'==1 {
            mat F=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
          }
          if `difj'==2 {
            mat F=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
          }
          if `difj'==3 {
            mat F=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
          }
          if `difj'==4 {
            mat F=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
          }
          if `difj'==5 {
            mat F=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
          }
          if `difj'==6 {
            mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
          }
          if `difj'==7 {
            mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
          }
          if `difk'==1 {
            mat G=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
          }
          if `difk'==2 {
            mat G=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
          }
          if `difk'==3 {
            mat G=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
          }
          if `difk'==4 {
            mat G=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
          }
          if `difk'==5 {
            mat G=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
          }
          if `difk'==6 {
            mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
          }
          if `difk'==7 {
            mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
          }
          mat D=B+E+F+G
      		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
          qui gen TT = 0
      		tempfile grp0
      		qui save `grp0',replace

          mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
      		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
          qui gen TT = 1
      		tempfile grp1
      		qui save `grp1',replace


      		clear
      		use `grp0'
          qui append using `grp1'
      		drop id
          qui gen dif1 = `difi'
          qui gen dif2 = `difj'
          qui gen dif3 = `difk'
      		qui gen id = _n
      		order(id)
      		qui gen replication = `replication'
      		if `replication'==1{
      			tempfile data
      			qui save `data'
      		}
      		else{
      			qui append using `data'
      			qui save `data',replace
      		}
      	}
      	export delimited using "`path'/scenario_17C_100.csv", replace







* Scenario 17D : H_1 is TRUE / Effect size 0.4 / DIF on treatment x3

        di "Scenario 17D - N=100"

          forvalues replication = 1/1000 {
            clear
            if mod(`replication',100)==0 {
            di "replication = `replication'"
            }
            qui set obs 7
            qui gen xxx = _n
            qui sample 3 ,count
            qui valuesof xxx
            qui local ItemsDIF = r(values)
            qui local difi :  word 1 of `ItemsDIF'
            qui local difj :  word 2 of `ItemsDIF'
            qui local difk :  word 3 of `ItemsDIF'



              mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
          		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
              qui gen TT = 0
          		tempfile grp0
          		qui save `grp0',replace


              mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
              if `difi'==1 {
                mat E=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difi'==2 {
                mat E=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difi'==3 {
                mat E=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
              }
              if `difi'==4 {
                mat E=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
              }
              if `difi'==5 {
                mat E=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
              }
              if `difi'==6 {
                mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
              }
              if `difi'==7 {
                mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
              }
              if `difj'==1 {
                mat F=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difj'==2 {
                mat F=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difj'==3 {
                mat F=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
              }
              if `difj'==4 {
                mat F=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
              }
              if `difj'==5 {
                mat F=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
              }
              if `difj'==6 {
                mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
              }
              if `difj'==7 {
                mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
              }
              if `difk'==1 {
                mat G=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difk'==2 {
                mat G=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difk'==3 {
                mat G=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
              }
              if `difk'==4 {
                mat G=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
              }
              if `difk'==5 {
                mat G=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
              }
              if `difk'==6 {
                mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
              }
              if `difk'==7 {
                mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
              }
              mat D=B+E+F+G
          		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
              qui gen TT = 1
          		tempfile grp1
          		qui save `grp1',replace


          		clear
          		use `grp0'
              qui append using `grp1'
          		drop id
              qui gen dif1 = `difi'
              qui gen dif2 = `difj'
              qui gen dif3 = `difk'
          		qui gen id = _n
          		order(id)
          		qui gen replication = `replication'
          		if `replication'==1{
          			tempfile data
          			qui save `data'
          		}
          		else{
          			qui append using `data'
          			qui save `data',replace
          		}
          	}
          	export delimited using "`path'/scenario_17D_100.csv", replace











* Scenario 17E : H_1 is TRUE / Effect size 0.4 / DIF on control x3

            di "Scenario 17E - N=100"

              forvalues replication = 1/1000 {
                  clear
                	if mod(`replication',100)==0 {
                	di "replication = `replication'"
                  }
                  qui set obs 7
                  qui gen xxx = _n
                  qui sample 3 ,count
                  qui valuesof xxx
                  qui local ItemsDIF = r(values)
                  qui local difi :  word 1 of `ItemsDIF'
                  qui local difj :  word 2 of `ItemsDIF'
                  qui local difk :  word 3 of `ItemsDIF'

                  mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
                  if `difi'==1 {
                    mat E=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difi'==2 {
                    mat E=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difi'==3 {
                    mat E=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difi'==4 {
                    mat E=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
                  }
                  if `difi'==5 {
                    mat E=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
                  }
                  if `difi'==6 {
                    mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
                  }
                  if `difi'==7 {
                    mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
                  }
                  if `difj'==1 {
                    mat F=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difj'==2 {
                    mat F=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difj'==3 {
                    mat F=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difj'==4 {
                    mat F=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
                  }
                  if `difj'==5 {
                    mat F=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
                  }
                  if `difj'==6 {
                    mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
                  }
                  if `difj'==7 {
                    mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
                  }
                  if `difk'==1 {
                    mat G=(0.3 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difk'==2 {
                    mat G=(0 \ 0.3 \ 0 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difk'==3 {
                    mat G=(0 \ 0 \ 0.3 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difk'==4 {
                    mat G=(0 \ 0 \ 0 \ 0.3 \ 0 \ 0 \ 0)
                  }
                  if `difk'==5 {
                    mat G=(0 \ 0 \ 0 \ 0 \ 0.3 \ 0 \ 0)
                  }
                  if `difk'==6 {
                    mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0.3 \ 0)
                  }
                  if `difk'==7 {
                    mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.3)
                  }
                  mat D=B+E+F+G
              		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
                  qui gen TT = 0
              		tempfile grp0
              		qui save `grp0',replace

                  mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
              		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
                  qui gen TT = 1
              		tempfile grp1
              		qui save `grp1',replace


              		clear
              		use `grp0'
                  qui append using `grp1'
              		drop id
                  qui gen dif1 = `difi'
                  qui gen dif2 = `difj'
                  qui gen dif3 = `difk'
              		qui gen id = _n
              		order(id)
              		qui gen replication = `replication'
              		if `replication'==1{
              			tempfile data
              			qui save `data'
              		}
              		else{
              			qui append using `data'
              			qui save `data',replace
              		}
              	}
              	export delimited using "`path'/scenario_17E_100.csv", replace







** Scenario 18: J = 7 items / M = 4 modalities / DIF SIZE = 0.3

* Scenario 18A : H_0 is TRUE / DIF on treatment x3
di "Scenario 18A - N=100"

forvalues replication = 1/1000 {
  clear
  if mod(`replication',100)==0 {
  di "replication = `replication'"
  }
  qui set obs 7
  qui gen xxx = _n
  qui sample 3 ,count
  qui valuesof xxx
  qui local ItemsDIF = r(values)
  qui local difi :  word 1 of `ItemsDIF'
  qui local difj :  word 2 of `ItemsDIF'
  qui local difk :  word 3 of `ItemsDIF'


    mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 0
		tempfile grp0
		qui save `grp0',replace


    mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
    if `difi'==1 {
      mat E=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==2 {
      mat E=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==3 {
      mat E=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==4 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==5 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==6 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
    }
    if `difi'==7 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
    }
    if `difj'==1 {
      mat F=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==2 {
      mat F=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==3 {
      mat F=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==4 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==5 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==6 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
    }
    if `difj'==7 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
    }
    if `difk'==1 {
      mat G=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difk'==2 {
      mat G=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difk'==3 {
      mat G=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difk'==4 {
      mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difk'==5 {
      mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
    }
    if `difk'==6 {
      mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
    }
    if `difk'==7 {
      mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
    }
    mat D=B+E+F+G
    di
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 1
		tempfile grp1
		qui save `grp1',replace


		clear
		use `grp0'
    qui append using `grp1'
		drop id
    qui gen dif1 = `difi'
    qui gen dif2 = `difj'
    qui gen dif3 = `difk'
		qui gen id = _n
		order(id)
		qui gen replication = `replication'
		if `replication'==1{
			tempfile data
			qui save `data'
		}
		else{
			qui append using `data'
			qui save `data',replace
		}
	}
	export delimited using "`path'/scenario_18A_100.csv", replace


* Scenario 18B : H_1 is TRUE / Effect size 0.2 / DIF on treatment x3

di "Scenario 18B - N=100"

  forvalues replication = 1/1000 {
    clear
    if mod(`replication',100)==0 {
    di "replication = `replication'"
    }
    qui set obs 7
    qui gen xxx = _n
    qui sample 3 ,count
    qui valuesof xxx
    qui local ItemsDIF = r(values)
    qui local difi :  word 1 of `ItemsDIF'
    qui local difj :  word 2 of `ItemsDIF'
    qui local difk :  word 3 of `ItemsDIF'



      mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
  		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
      qui gen TT = 0
  		tempfile grp0
  		qui save `grp0',replace


      mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
      if `difi'==1 {
        mat E=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==2 {
        mat E=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==3 {
        mat E=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==4 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==5 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==6 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
      }
      if `difi'==7 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
      }
      if `difj'==1 {
        mat F=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==2 {
        mat F=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==3 {
        mat F=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==4 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==5 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==6 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
      }
      if `difj'==7 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
      }
      if `difk'==1 {
        mat G=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difk'==2 {
        mat G=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difk'==3 {
        mat G=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difk'==4 {
        mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difk'==5 {
        mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
      }
      if `difk'==6 {
        mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
      }
      if `difk'==7 {
        mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
      }
      mat D=B+E+F+G
  		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
      qui gen TT = 1
  		tempfile grp1
  		qui save `grp1',replace


  		clear
  		use `grp0'
      qui append using `grp1'
  		drop id
      qui gen dif1 = `difi'
      qui gen dif2 = `difj'
      qui gen dif3 = `difk'
  		qui gen id = _n
  		order(id)
  		qui gen replication = `replication'
  		if `replication'==1{
  			tempfile data
  			qui save `data'
  		}
  		else{
  			qui append using `data'
  			qui save `data',replace
  		}
  	}
  	export delimited using "`path'/scenario_18B_100.csv", replace











* Scenario 18C : H_1 is TRUE / Effect size 0.2 / DIF on control x3

    di "Scenario 18C - N=100"

      forvalues replication = 1/1000 {
        clear
        if mod(`replication',100)==0 {
        di "replication = `replication'"
        }
        qui set obs 7
        qui gen xxx = _n
        qui sample 3 ,count
        qui valuesof xxx
        qui local ItemsDIF = r(values)
        qui local difi :  word 1 of `ItemsDIF'
        qui local difj :  word 2 of `ItemsDIF'
        qui local difk :  word 3 of `ItemsDIF'



        mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
        if `difi'==1 {
          mat E=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difi'==2 {
          mat E=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difi'==3 {
          mat E=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difi'==4 {
          mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difi'==5 {
          mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
        }
        if `difi'==6 {
          mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
        }
        if `difi'==7 {
          mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
        }
        if `difj'==1 {
          mat F=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difj'==2 {
          mat F=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difj'==3 {
          mat F=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difj'==4 {
          mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difj'==5 {
          mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
        }
        if `difj'==6 {
          mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
        }
        if `difj'==7 {
          mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
        }
        if `difk'==1 {
          mat G=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difk'==2 {
          mat G=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difk'==3 {
          mat G=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difk'==4 {
          mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difk'==5 {
          mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
        }
        if `difk'==6 {
          mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
        }
        if `difk'==7 {
          mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
        }
          mat D=B+E+F+G
      		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
          qui gen TT = 0
      		tempfile grp0
      		qui save `grp0',replace

          mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
      		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
          qui gen TT = 1
      		tempfile grp1
      		qui save `grp1',replace


      		clear
      		use `grp0'
          qui append using `grp1'
      		drop id
          qui gen dif1 = `difi'
          qui gen dif2 = `difj'
          qui gen dif3 = `difk'
      		qui gen id = _n
      		order(id)
      		qui gen replication = `replication'
      		if `replication'==1{
      			tempfile data
      			qui save `data'
      		}
      		else{
      			qui append using `data'
      			qui save `data',replace
      		}
      	}
      	export delimited using "`path'/scenario_18C_100.csv", replace







* Scenario 18D : H_1 is TRUE / Effect size 0.4 / DIF on treatment x3

        di "Scenario 18D - N=100"

          forvalues replication = 1/1000 {
            clear
            if mod(`replication',100)==0 {
            di "replication = `replication'"
            }
            qui set obs 7
            qui gen xxx = _n
            qui sample 3 ,count
            qui valuesof xxx
            qui local ItemsDIF = r(values)
            qui local difi :  word 1 of `ItemsDIF'
            qui local difj :  word 2 of `ItemsDIF'
            qui local difk :  word 3 of `ItemsDIF'



              mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
          		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
              qui gen TT = 0
          		tempfile grp0
          		qui save `grp0',replace


              mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
              if `difi'==1 {
                mat E=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difi'==2 {
                mat E=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difi'==3 {
                mat E=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difi'==4 {
                mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difi'==5 {
                mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
              }
              if `difi'==6 {
                mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
              }
              if `difi'==7 {
                mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
              }
              if `difj'==1 {
                mat F=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difj'==2 {
                mat F=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difj'==3 {
                mat F=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difj'==4 {
                mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difj'==5 {
                mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
              }
              if `difj'==6 {
                mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
              }
              if `difj'==7 {
                mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
              }
              if `difk'==1 {
                mat G=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difk'==2 {
                mat G=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difk'==3 {
                mat G=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difk'==4 {
                mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difk'==5 {
                mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
              }
              if `difk'==6 {
                mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
              }
              if `difk'==7 {
                mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
              }
              mat D=B+E+F+G
          		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
              qui gen TT = 1
          		tempfile grp1
          		qui save `grp1',replace


          		clear
          		use `grp0'
              qui append using `grp1'
          		drop id
              qui gen dif1 = `difi'
              qui gen dif2 = `difj'
              qui gen dif3 = `difk'
          		qui gen id = _n
          		order(id)
          		qui gen replication = `replication'
          		if `replication'==1{
          			tempfile data
          			qui save `data'
          		}
          		else{
          			qui append using `data'
          			qui save `data',replace
          		}
          	}
          	export delimited using "`path'/scenario_18D_100.csv", replace











* Scenario 18E : H_1 is TRUE / Effect size 0.4 / DIF on control x3

            di "Scenario 18E - N=100"

              forvalues replication = 1/1000 {
                  clear
                	if mod(`replication',100)==0 {
                	di "replication = `replication'"
                  }
                  qui set obs 7
                  qui gen xxx = _n
                  qui sample 3 ,count
                  qui valuesof xxx
                  qui local ItemsDIF = r(values)
                  qui local difi :  word 1 of `ItemsDIF'
                  qui local difj :  word 2 of `ItemsDIF'
                  qui local difk :  word 3 of `ItemsDIF'

                  mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
                  if `difi'==1 {
                    mat E=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difi'==2 {
                    mat E=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difi'==3 {
                    mat E=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difi'==4 {
                    mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difi'==5 {
                    mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
                  }
                  if `difi'==6 {
                    mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
                  }
                  if `difi'==7 {
                    mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
                  }
                  if `difj'==1 {
                    mat F=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difj'==2 {
                    mat F=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difj'==3 {
                    mat F=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difj'==4 {
                    mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difj'==5 {
                    mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
                  }
                  if `difj'==6 {
                    mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
                  }
                  if `difj'==7 {
                    mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
                  }
                  if `difk'==1 {
                    mat G=(0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difk'==2 {
                    mat G=(0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difk'==3 {
                    mat G=(0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difk'==4 {
                    mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difk'==5 {
                    mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0 \ 0,0,0)
                  }
                  if `difk'==6 {
                    mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3 \ 0,0,0)
                  }
                  if `difk'==7 {
                    mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.3,0.3,0.3)
                  }
                  mat D=B+E+F+G
              		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
                  qui gen TT = 0
              		tempfile grp0
              		qui save `grp0',replace

                  mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
              		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
                  qui gen TT = 1
              		tempfile grp1
              		qui save `grp1',replace


              		clear
              		use `grp0'
                  qui append using `grp1'
              		drop id
                  qui gen dif1 = `difi'
                  qui gen dif2 = `difj'
                  qui gen dif3 = `difk'
              		qui gen id = _n
              		order(id)
              		qui gen replication = `replication'
              		if `replication'==1{
              			tempfile data
              			qui save `data'
              		}
              		else{
              			qui append using `data'
              			qui save `data',replace
              		}
              	}
              	export delimited using "`path'/scenario_18E_100.csv", replace












**** Scenarios with : DIF size 0.5 ****


** Scenario 19: J = 7 items / M = 2 modalities / DIF SIZE = 0.3

* Scenario 19A : H_0 is TRUE / DIF on treatment x3
di "Scenario 19A - N=100"

forvalues replication = 1/1000 {
  clear
  if mod(`replication',100)==0 {
  di "replication = `replication'"
  }
  qui set obs 7
  qui gen xxx = _n
  qui sample 3 ,count
  qui valuesof xxx
  qui local ItemsDIF = r(values)
  qui local difi :  word 1 of `ItemsDIF'
  qui local difj :  word 2 of `ItemsDIF'
  qui local difk :  word 3 of `ItemsDIF'


    mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 0
		tempfile grp0
		qui save `grp0',replace


    mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
    if `difi'==1 {
      mat E=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difi'==2 {
      mat E=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difi'==3 {
      mat E=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
    }
    if `difi'==4 {
      mat E=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
    }
    if `difi'==5 {
      mat E=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
    }
    if `difi'==6 {
      mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
    }
    if `difi'==7 {
      mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
    }
    if `difj'==1 {
      mat F=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difj'==2 {
      mat F=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difj'==3 {
      mat F=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
    }
    if `difj'==4 {
      mat F=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
    }
    if `difj'==5 {
      mat F=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
    }
    if `difj'==6 {
      mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
    }
    if `difj'==7 {
      mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
    }
    if `difk'==1 {
      mat G=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difk'==2 {
      mat G=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
    }
    if `difk'==3 {
      mat G=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
    }
    if `difk'==4 {
      mat G=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
    }
    if `difk'==5 {
      mat G=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
    }
    if `difk'==6 {
      mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
    }
    if `difk'==7 {
      mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
    }
    mat D=B+E+F+G
    di
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 1
		tempfile grp1
		qui save `grp1',replace


		clear
		use `grp0'
    qui append using `grp1'
		drop id
    qui gen dif1 = `difi'
    qui gen dif2 = `difj'
    qui gen dif3 = `difk'
		qui gen id = _n
		order(id)
		qui gen replication = `replication'
		if `replication'==1{
			tempfile data
			qui save `data'
		}
		else{
			qui append using `data'
			qui save `data',replace
		}
	}
	export delimited using "`path'/scenario_19A_100.csv", replace


* Scenario 19B : H_1 is TRUE / Effect size 0.2 / DIF on treatment x3

di "Scenario 19B - N=100"

  forvalues replication = 1/1000 {
    clear
    if mod(`replication',100)==0 {
    di "replication = `replication'"
    }
    qui set obs 7
    qui gen xxx = _n
    qui sample 3 ,count
    qui valuesof xxx
    qui local ItemsDIF = r(values)
    qui local difi :  word 1 of `ItemsDIF'
    qui local difj :  word 2 of `ItemsDIF'
    qui local difk :  word 3 of `ItemsDIF'



      mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
  		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
      qui gen TT = 0
  		tempfile grp0
  		qui save `grp0',replace


      mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
      if `difi'==1 {
        mat E=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==2 {
        mat E=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==3 {
        mat E=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
      }
      if `difi'==4 {
        mat E=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
      }
      if `difi'==5 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
      }
      if `difi'==6 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
      }
      if `difi'==7 {
        mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
      }
      if `difj'==1 {
        mat F=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==2 {
        mat F=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==3 {
        mat F=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
      }
      if `difj'==4 {
        mat F=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
      }
      if `difj'==5 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
      }
      if `difj'==6 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
      }
      if `difj'==7 {
        mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
      }
      if `difk'==1 {
        mat G=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difk'==2 {
        mat G=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
      }
      if `difk'==3 {
        mat G=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
      }
      if `difk'==4 {
        mat G=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
      }
      if `difk'==5 {
        mat G=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
      }
      if `difk'==6 {
        mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
      }
      if `difk'==7 {
        mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
      }
      mat D=B+E+F+G
  		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
      qui gen TT = 1
  		tempfile grp1
  		qui save `grp1',replace


  		clear
  		use `grp0'
      qui append using `grp1'
  		drop id
      qui gen dif1 = `difi'
      qui gen dif2 = `difj'
      qui gen dif3 = `difk'
  		qui gen id = _n
  		order(id)
  		qui gen replication = `replication'
  		if `replication'==1{
  			tempfile data
  			qui save `data'
  		}
  		else{
  			qui append using `data'
  			qui save `data',replace
  		}
  	}
  	export delimited using "`path'/scenario_19B_100.csv", replace



* Scenario 19C : H_1 is TRUE / Effect size 0.2 / DIF on control x3

    di "Scenario 19C - N=100"

      forvalues replication = 1/1000 {
        clear
        if mod(`replication',100)==0 {
        di "replication = `replication'"
        }
        qui set obs 7
        qui gen xxx = _n
        qui sample 3 ,count
        qui valuesof xxx
        qui local ItemsDIF = r(values)
        qui local difi :  word 1 of `ItemsDIF'
        qui local difj :  word 2 of `ItemsDIF'
        qui local difk :  word 3 of `ItemsDIF'



          mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
          if `difi'==1 {
            mat E=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
          }
          if `difi'==2 {
            mat E=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
          }
          if `difi'==3 {
            mat E=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
          }
          if `difi'==4 {
            mat E=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
          }
          if `difi'==5 {
            mat E=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
          }
          if `difi'==6 {
            mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
          }
          if `difi'==7 {
            mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
          }
          if `difj'==1 {
            mat F=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
          }
          if `difj'==2 {
            mat F=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
          }
          if `difj'==3 {
            mat F=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
          }
          if `difj'==4 {
            mat F=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
          }
          if `difj'==5 {
            mat F=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
          }
          if `difj'==6 {
            mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
          }
          if `difj'==7 {
            mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
          }
          if `difk'==1 {
            mat G=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
          }
          if `difk'==2 {
            mat G=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
          }
          if `difk'==3 {
            mat G=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
          }
          if `difk'==4 {
            mat G=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
          }
          if `difk'==5 {
            mat G=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
          }
          if `difk'==6 {
            mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
          }
          if `difk'==7 {
            mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
          }
          mat D=B+E+F+G
      		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
          qui gen TT = 0
      		tempfile grp0
      		qui save `grp0',replace

          mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
      		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
          qui gen TT = 1
      		tempfile grp1
      		qui save `grp1',replace


      		clear
      		use `grp0'
          qui append using `grp1'
      		drop id
          qui gen dif1 = `difi'
          qui gen dif2 = `difj'
          qui gen dif3 = `difk'
      		qui gen id = _n
      		order(id)
      		qui gen replication = `replication'
      		if `replication'==1{
      			tempfile data
      			qui save `data'
      		}
      		else{
      			qui append using `data'
      			qui save `data',replace
      		}
      	}
      	export delimited using "`path'/scenario_19C_100.csv", replace



* Scenario 19D : H_1 is TRUE / Effect size 0.4 / DIF on treatment x3

        di "Scenario 19D - N=100"

          forvalues replication = 1/1000 {
            clear
            if mod(`replication',100)==0 {
            di "replication = `replication'"
            }
            qui set obs 7
            qui gen xxx = _n
            qui sample 3 ,count
            qui valuesof xxx
            qui local ItemsDIF = r(values)
            qui local difi :  word 1 of `ItemsDIF'
            qui local difj :  word 2 of `ItemsDIF'
            qui local difk :  word 3 of `ItemsDIF'



              mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
          		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
              qui gen TT = 0
          		tempfile grp0
          		qui save `grp0',replace


              mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
              if `difi'==1 {
                mat E=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difi'==2 {
                mat E=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difi'==3 {
                mat E=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
              }
              if `difi'==4 {
                mat E=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
              }
              if `difi'==5 {
                mat E=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
              }
              if `difi'==6 {
                mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
              }
              if `difi'==7 {
                mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
              }
              if `difj'==1 {
                mat F=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difj'==2 {
                mat F=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difj'==3 {
                mat F=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
              }
              if `difj'==4 {
                mat F=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
              }
              if `difj'==5 {
                mat F=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
              }
              if `difj'==6 {
                mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
              }
              if `difj'==7 {
                mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
              }
              if `difk'==1 {
                mat G=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difk'==2 {
                mat G=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
              }
              if `difk'==3 {
                mat G=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
              }
              if `difk'==4 {
                mat G=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
              }
              if `difk'==5 {
                mat G=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
              }
              if `difk'==6 {
                mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
              }
              if `difk'==7 {
                mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
              }
              mat D=B+E+F+G
          		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
              qui gen TT = 1
          		tempfile grp1
          		qui save `grp1',replace


          		clear
          		use `grp0'
              qui append using `grp1'
          		drop id
              qui gen dif1 = `difi'
              qui gen dif2 = `difj'
              qui gen dif3 = `difk'
          		qui gen id = _n
          		order(id)
          		qui gen replication = `replication'
          		if `replication'==1{
          			tempfile data
          			qui save `data'
          		}
          		else{
          			qui append using `data'
          			qui save `data',replace
          		}
          	}
          	export delimited using "`path'/scenario_19D_100.csv", replace



* Scenario 19E : H_1 is TRUE / Effect size 0.4 / DIF on control x3

            di "Scenario 19E - N=100"

              forvalues replication = 1/1000 {
                  clear
                	if mod(`replication',100)==0 {
                	di "replication = `replication'"
                  }
                  qui set obs 7
                  qui gen xxx = _n
                  qui sample 3 ,count
                  qui valuesof xxx
                  qui local ItemsDIF = r(values)
                  qui local difi :  word 1 of `ItemsDIF'
                  qui local difj :  word 2 of `ItemsDIF'
                  qui local difk :  word 3 of `ItemsDIF'

                  mat B= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
                  if `difi'==1 {
                    mat E=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difi'==2 {
                    mat E=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difi'==3 {
                    mat E=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difi'==4 {
                    mat E=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
                  }
                  if `difi'==5 {
                    mat E=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
                  }
                  if `difi'==6 {
                    mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
                  }
                  if `difi'==7 {
                    mat E=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
                  }
                  if `difj'==1 {
                    mat F=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difj'==2 {
                    mat F=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difj'==3 {
                    mat F=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difj'==4 {
                    mat F=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
                  }
                  if `difj'==5 {
                    mat F=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
                  }
                  if `difj'==6 {
                    mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
                  }
                  if `difj'==7 {
                    mat F=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
                  }
                  if `difk'==1 {
                    mat G=(0.5 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difk'==2 {
                    mat G=(0 \ 0.5 \ 0 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difk'==3 {
                    mat G=(0 \ 0 \ 0.5 \ 0 \ 0 \ 0 \ 0)
                  }
                  if `difk'==4 {
                    mat G=(0 \ 0 \ 0 \ 0.5 \ 0 \ 0 \ 0)
                  }
                  if `difk'==5 {
                    mat G=(0 \ 0 \ 0 \ 0 \ 0.5 \ 0 \ 0)
                  }
                  if `difk'==6 {
                    mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0.5 \ 0)
                  }
                  if `difk'==7 {
                    mat G=(0 \ 0 \ 0 \ 0 \ 0 \ 0 \ 0.5)
                  }
                  mat D=B+E+F+G
              		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
                  qui gen TT = 0
              		tempfile grp0
              		qui save `grp0',replace

                  mat D= (-1.15 \ -0.67 \ -0.32 \ 0 \ 0.32 \ 0.67 \ 1.15)
              		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
                  qui gen TT = 1
              		tempfile grp1
              		qui save `grp1',replace


              		clear
              		use `grp0'
                  qui append using `grp1'
              		drop id
                  qui gen dif1 = `difi'
                  qui gen dif2 = `difj'
                  qui gen dif3 = `difk'
              		qui gen id = _n
              		order(id)
              		qui gen replication = `replication'
              		if `replication'==1{
              			tempfile data
              			qui save `data'
              		}
              		else{
              			qui append using `data'
              			qui save `data',replace
              		}
              	}
              	export delimited using "`path'/scenario_19E_100.csv", replace






** Scenario 20: J = 7 items / M = 4 modalities / DIF SIZE = 0.3

* Scenario 20A : H_0 is TRUE / DIF on treatment x3
di "Scenario 20A - N=100"

forvalues replication = 1/1000 {
  clear
  if mod(`replication',100)==0 {
  di "replication = `replication'"
  }
  qui set obs 7
  qui gen xxx = _n
  qui sample 3 ,count
  qui valuesof xxx
  qui local ItemsDIF = r(values)
  qui local difi :  word 1 of `ItemsDIF'
  qui local difj :  word 2 of `ItemsDIF'
  qui local difk :  word 3 of `ItemsDIF'


    mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 0
		tempfile grp0
		qui save `grp0',replace


    mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
    if `difi'==1 {
      mat E=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==2 {
      mat E=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==3 {
      mat E=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==4 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==5 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
    }
    if `difi'==6 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
    }
    if `difi'==7 {
      mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
    }
    if `difj'==1 {
      mat F=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==2 {
      mat F=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==3 {
      mat F=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==4 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==5 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
    }
    if `difj'==6 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
    }
    if `difj'==7 {
      mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
    }
    if `difk'==1 {
      mat G=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difk'==2 {
      mat G=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difk'==3 {
      mat G=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difk'==4 {
      mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
    }
    if `difk'==5 {
      mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
    }
    if `difk'==6 {
      mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
    }
    if `difk'==7 {
      mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
    }
    mat D=B+E+F+G
    di
		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
    qui gen TT = 1
		tempfile grp1
		qui save `grp1',replace


		clear
		use `grp0'
    qui append using `grp1'
		drop id
    qui gen dif1 = `difi'
    qui gen dif2 = `difj'
    qui gen dif3 = `difk'
		qui gen id = _n
		order(id)
		qui gen replication = `replication'
		if `replication'==1{
			tempfile data
			qui save `data'
		}
		else{
			qui append using `data'
			qui save `data',replace
		}
	}
	export delimited using "`path'/scenario_20A_100.csv", replace


* Scenario 20B : H_1 is TRUE / Effect size 0.2 / DIF on treatment x3

di "Scenario 20B - N=100"

  forvalues replication = 1/1000 {
    clear
    if mod(`replication',100)==0 {
    di "replication = `replication'"
    }
    qui set obs 7
    qui gen xxx = _n
    qui sample 3 ,count
    qui valuesof xxx
    qui local ItemsDIF = r(values)
    qui local difi :  word 1 of `ItemsDIF'
    qui local difj :  word 2 of `ItemsDIF'
    qui local difk :  word 3 of `ItemsDIF'



      mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
  		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
      qui gen TT = 0
  		tempfile grp0
  		qui save `grp0',replace


      mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
      if `difi'==1 {
        mat E=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==2 {
        mat E=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==3 {
        mat E=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==4 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==5 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
      }
      if `difi'==6 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
      }
      if `difi'==7 {
        mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
      }
      if `difj'==1 {
        mat F=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==2 {
        mat F=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==3 {
        mat F=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==4 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==5 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
      }
      if `difj'==6 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
      }
      if `difj'==7 {
        mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
      }
      if `difk'==1 {
        mat G=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difk'==2 {
        mat G=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difk'==3 {
        mat G=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difk'==4 {
        mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
      }
      if `difk'==5 {
        mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
      }
      if `difk'==6 {
        mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
      }
      if `difk'==7 {
        mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
      }
      mat D=B+E+F+G
  		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
      qui gen TT = 1
  		tempfile grp1
  		qui save `grp1',replace


  		clear
  		use `grp0'
      qui append using `grp1'
  		drop id
      qui gen dif1 = `difi'
      qui gen dif2 = `difj'
      qui gen dif3 = `difk'
  		qui gen id = _n
  		order(id)
  		qui gen replication = `replication'
  		if `replication'==1{
  			tempfile data
  			qui save `data'
  		}
  		else{
  			qui append using `data'
  			qui save `data',replace
  		}
  	}
  	export delimited using "`path'/scenario_20B_100.csv", replace


* Scenario 20C : H_1 is TRUE / Effect size 0.2 / DIF on control x3

    di "Scenario 20C - N=100"

      forvalues replication = 1/1000 {
        clear
        if mod(`replication',100)==0 {
        di "replication = `replication'"
        }
        qui set obs 7
        qui gen xxx = _n
        qui sample 3 ,count
        qui valuesof xxx
        qui local ItemsDIF = r(values)
        qui local difi :  word 1 of `ItemsDIF'
        qui local difj :  word 2 of `ItemsDIF'
        qui local difk :  word 3 of `ItemsDIF'



        mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
        if `difi'==1 {
          mat E=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difi'==2 {
          mat E=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difi'==3 {
          mat E=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difi'==4 {
          mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difi'==5 {
          mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
        }
        if `difi'==6 {
          mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
        }
        if `difi'==7 {
          mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
        }
        if `difj'==1 {
          mat F=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difj'==2 {
          mat F=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difj'==3 {
          mat F=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difj'==4 {
          mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difj'==5 {
          mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
        }
        if `difj'==6 {
          mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
        }
        if `difj'==7 {
          mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
        }
        if `difk'==1 {
          mat G=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difk'==2 {
          mat G=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difk'==3 {
          mat G=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difk'==4 {
          mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
        }
        if `difk'==5 {
          mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
        }
        if `difk'==6 {
          mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
        }
        if `difk'==7 {
          mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
        }
          mat D=B+E+F+G
      		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
          qui gen TT = 0
      		tempfile grp0
      		qui save `grp0',replace

          mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
      		qui simirt, nbobs(`Nn') mu(0.2) cov(1) dim(7) pcm(D) clear
          qui gen TT = 1
      		tempfile grp1
      		qui save `grp1',replace


      		clear
      		use `grp0'
          qui append using `grp1'
      		drop id
          qui gen dif1 = `difi'
          qui gen dif2 = `difj'
          qui gen dif3 = `difk'
      		qui gen id = _n
      		order(id)
      		qui gen replication = `replication'
      		if `replication'==1{
      			tempfile data
      			qui save `data'
      		}
      		else{
      			qui append using `data'
      			qui save `data',replace
      		}
      	}
      	export delimited using "`path'/scenario_20C_100.csv", replace



* Scenario 20D : H_1 is TRUE / Effect size 0.4 / DIF on treatment x3

        di "Scenario 20D - N=100"

          forvalues replication = 1/1000 {
            clear
            if mod(`replication',100)==0 {
            di "replication = `replication'"
            }
            qui set obs 7
            qui gen xxx = _n
            qui sample 3 ,count
            qui valuesof xxx
            qui local ItemsDIF = r(values)
            qui local difi :  word 1 of `ItemsDIF'
            qui local difj :  word 2 of `ItemsDIF'
            qui local difk :  word 3 of `ItemsDIF'



              mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
          		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
              qui gen TT = 0
          		tempfile grp0
          		qui save `grp0',replace


              mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
              if `difi'==1 {
                mat E=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difi'==2 {
                mat E=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difi'==3 {
                mat E=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difi'==4 {
                mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difi'==5 {
                mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
              }
              if `difi'==6 {
                mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
              }
              if `difi'==7 {
                mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
              }
              if `difj'==1 {
                mat F=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difj'==2 {
                mat F=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difj'==3 {
                mat F=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difj'==4 {
                mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difj'==5 {
                mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
              }
              if `difj'==6 {
                mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
              }
              if `difj'==7 {
                mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
              }
              if `difk'==1 {
                mat G=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difk'==2 {
                mat G=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difk'==3 {
                mat G=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difk'==4 {
                mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
              }
              if `difk'==5 {
                mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
              }
              if `difk'==6 {
                mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
              }
              if `difk'==7 {
                mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
              }
              mat D=B+E+F+G
          		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
              qui gen TT = 1
          		tempfile grp1
          		qui save `grp1',replace


          		clear
          		use `grp0'
              qui append using `grp1'
          		drop id
              qui gen dif1 = `difi'
              qui gen dif2 = `difj'
              qui gen dif3 = `difk'
          		qui gen id = _n
          		order(id)
          		qui gen replication = `replication'
          		if `replication'==1{
          			tempfile data
          			qui save `data'
          		}
          		else{
          			qui append using `data'
          			qui save `data',replace
          		}
          	}
          	export delimited using "`path'/scenario_20D_100.csv", replace



* Scenario 20E : H_1 is TRUE / Effect size 0.4 / DIF on control x3

            di "Scenario 20E - N=100"

              forvalues replication = 1/1000 {
                  clear
                	if mod(`replication',100)==0 {
                	di "replication = `replication'"
                  }
                  qui set obs 7
                  qui gen xxx = _n
                  qui sample 3 ,count
                  qui valuesof xxx
                  qui local ItemsDIF = r(values)
                  qui local difi :  word 1 of `ItemsDIF'
                  qui local difj :  word 2 of `ItemsDIF'
                  qui local difk :  word 3 of `ItemsDIF'

                  mat B= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
                  if `difi'==1 {
                    mat E=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difi'==2 {
                    mat E=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difi'==3 {
                    mat E=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difi'==4 {
                    mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difi'==5 {
                    mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
                  }
                  if `difi'==6 {
                    mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
                  }
                  if `difi'==7 {
                    mat E=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
                  }
                  if `difj'==1 {
                    mat F=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difj'==2 {
                    mat F=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difj'==3 {
                    mat F=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difj'==4 {
                    mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difj'==5 {
                    mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
                  }
                  if `difj'==6 {
                    mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
                  }
                  if `difj'==7 {
                    mat F=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
                  }
                  if `difk'==1 {
                    mat G=(0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difk'==2 {
                    mat G=(0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difk'==3 {
                    mat G=(0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difk'==4 {
                    mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0 \ 0,0,0)
                  }
                  if `difk'==5 {
                    mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0 \ 0,0,0)
                  }
                  if `difk'==6 {
                    mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5 \ 0,0,0)
                  }
                  if `difk'==7 {
                    mat G=(0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0,0,0 \ 0.5,0.5,0.5)
                  }
                  mat D=B+E+F+G
              		qui simirt, nbobs(`Nn') mu(0) cov(1) dim(7) pcm(D) clear
                  qui gen TT = 0
              		tempfile grp0
              		qui save `grp0',replace

                  mat D= (-2.15,-1.15,-0.15 \ -1.67,-0.67,0.33 \ -1.32,-0.32,0.68 \ -1,0,1 \ -0.68,0.32,1.32 \ -0.33,0.67,1.67 \ 0.15,1.15,2.15)
              		qui simirt, nbobs(`Nn') mu(0.4) cov(1) dim(7) pcm(D) clear
                  qui gen TT = 1
              		tempfile grp1
              		qui save `grp1',replace


              		clear
              		use `grp0'
                  qui append using `grp1'
              		drop id
                  qui gen dif1 = `difi'
                  qui gen dif2 = `difj'
                  qui gen dif3 = `difk'
              		qui gen id = _n
              		order(id)
              		qui gen replication = `replication'
              		if `replication'==1{
              			tempfile data
              			qui save `data'
              		}
              		else{
              			qui append using `data'
              			qui save `data',replace
              		}
              	}
              	export delimited using "`path'/scenario_20E_100.csv", replace
